powered by
Tests whether treatment effects are equal across score groups.
het.test(T, tau, Y, ngates = 5, centered = TRUE)
A list with test statistic stat and p-value pval.
stat
pval
Binary treatment indicator (0 or 1).
Continuous score vector.
Outcome vector.
Number of groups (at least 2).
Whether to center outcomes before estimation.
Michael Lingzhi Li, Technology and Operations Management, Harvard Business School mili@hbs.edu, https://www.michaellz.com/;
See GATE for inference details.
GATE
Imai and Li (2022). “Statistical Inference for Heterogeneous Treatment Effects Discovered by Generic Machine Learning in Randomized Experiments”,
T = c(1,0,1,0,1,0,1,0) tau = c(0,0.1,0.2,0.3,0.4,0.5,0.6,0.7) Y = c(4,5,0,2,4,1,-4,3) hettestlist <- het.test(T,tau,Y,ngates=2) hettestlist$stat hettestlist$pval
Run the code above in your browser using DataLab